#ifndef ROMAN_CONVERT_TBL_H
#define ROMAN_CONVERT_TBL_H

/*!
  \file
  \brief [}Eȕϊe[u()

  \author Satofumi KAMIMURA

  $Id$
*/

#include <SDL.h>


namespace beego {
  enum { ROMAN_CONVERT_SIZE_MAX = 5 };

  /*!
    \brief Roman ϊp Unicode z
  */
  const static Uint16 RomanTable[][2][5] = {
    { { 'a', 0x00 }, { 0x3042, 0x00 }, }, // 
    { { 'i', 0x00 }, { 0x3044, 0x00 }, }, // 
    { { 'u', 0x00 }, { 0x3046, 0x00 }, }, // 
    { { 'e', 0x00 }, { 0x3048, 0x00 }, }, // 
    { { 'o', 0x00 }, { 0x304a, 0x00 }, }, // 
    { { 'k','a', 0x00 }, { 0x304b, 0x00 }, }, // 
    { { 'k','i', 0x00 }, { 0x304d, 0x00 }, }, // 
    { { 'k','u', 0x00 }, { 0x304f, 0x00 }, }, // 
    { { 'k','e', 0x00 }, { 0x3051, 0x00 }, }, // 
    { { 'k','o', 0x00 }, { 0x3053, 0x00 }, }, // 
    { { 'k','y','a', 0x00 }, { 0x304d, 0x3083, 0x00 }, }, // 
    { { 'k','y','i', 0x00 }, { 0x304d, 0x3043, 0x00 }, }, // 
    { { 'k','y','u', 0x00 }, { 0x304d, 0x3085, 0x00 }, }, // 
    { { 'k','y','e', 0x00 }, { 0x304d, 0x3047, 0x00 }, }, // 
    { { 'k','y','o', 0x00 }, { 0x304d, 0x3087, 0x00 }, }, // 
    { { 'k','w','a', 0x00 }, { 0x304f, 0x3041, 0x00 }, }, // 
    { { 's','a', 0x00 }, { 0x3055, 0x00 }, }, // 
    { { 's','i', 0x00 }, { 0x3057, 0x00 }, }, // 
    { { 's','h','i', 0x00 }, { 0x3057, 0x00 }, }, // 
    { { 's','u', 0x00 }, { 0x3059, 0x00 }, }, // 
    { { 's','e', 0x00 }, { 0x305b, 0x00 }, }, // 
    { { 's','o', 0x00 }, { 0x305d, 0x00 }, }, // 
    { { 's','y','a', 0x00 }, { 0x3057, 0x3083, 0x00 }, }, // 
    { { 's','h','a', 0x00 }, { 0x3057, 0x3083, 0x00 }, }, // 
    { { 's','y','i', 0x00 }, { 0x3057, 0x3043, 0x00 }, }, // 
    { { 's','y','u', 0x00 }, { 0x3057, 0x3085, 0x00 }, }, // 
    { { 's','h','u', 0x00 }, { 0x3057, 0x3085, 0x00 }, }, // 
    { { 's','y','e', 0x00 }, { 0x3057, 0x3047, 0x00 }, }, // 
    { { 's','h','e', 0x00 }, { 0x3057, 0x3047, 0x00 }, }, // 
    { { 's','y','o', 0x00 }, { 0x3057, 0x3087, 0x00 }, }, // 
    { { 's','h','o', 0x00 }, { 0x3057, 0x3087, 0x00 }, }, // 
    { { 't','a', 0x00 }, { 0x305f, 0x00 }, }, // 
    { { 't','i', 0x00 }, { 0x3061, 0x00 }, }, // 
    { { 'c','h','i', 0x00 }, { 0x3061, 0x00 }, }, // 
    { { 't','u', 0x00 }, { 0x3064, 0x00 }, }, // 
    { { 't','s','u', 0x00 }, { 0x3064, 0x00 }, }, // 
    { { 't','e', 0x00 }, { 0x3066, 0x00 }, }, // 
    { { 't','o', 0x00 }, { 0x3068, 0x00 }, }, // 
    { { 'b','b', 0x00 }, { 0x3063, 0x0062, 0x00 }, }, // b
    { { 'c','c', 0x00 }, { 0x3063, 0x0063, 0x00 }, }, // c
    { { 'd','d', 0x00 }, { 0x3063, 0x0064, 0x00 }, }, // d
    { { 'f','f', 0x00 }, { 0x3063, 0x0066, 0x00 }, }, // f
    { { 'g','g', 0x00 }, { 0x3063, 0x0067, 0x00 }, }, // g
    { { 'h','h', 0x00 }, { 0x3063, 0x0068, 0x00 }, }, // h
    { { 'j','j', 0x00 }, { 0x3063, 0x006a, 0x00 }, }, // j
    { { 'k','k', 0x00 }, { 0x3063, 0x006b, 0x00 }, }, // k
    { { 'l','l', 0x00 }, { 0x3063, 0x006c, 0x00 }, }, // l
    { { 'm','m', 0x00 }, { 0x3063, 0x006d, 0x00 }, }, // m
    { { 'p','p', 0x00 }, { 0x3063, 0x0070, 0x00 }, }, // p
    { { 'q','q', 0x00 }, { 0x3063, 0x0071, 0x00 }, }, // q
    { { 'r','r', 0x00 }, { 0x3063, 0x0072, 0x00 }, }, // r
    { { 's','s', 0x00 }, { 0x3063, 0x0073, 0x00 }, }, // s
    { { 't','t', 0x00 }, { 0x3063, 0x0074, 0x00 }, }, // t
    { { 'v','v', 0x00 }, { 0x3063, 0x0076, 0x00 }, }, // v
    { { 'w','w', 0x00 }, { 0x3063, 0x0077, 0x00 }, }, // w
    { { 'z','z', 0x00 }, { 0x3063, 0x007a, 0x00 }, }, // z
    { { 'x','t','u', 0x00 }, { 0x3063, 0x00 }, }, // 
    { { 'l','t','u', 0x00 }, { 0x3063, 0x00 }, }, // 
    { { 'l','t','s','u', 0x00 }, { 0x3063, 0x00 }, }, // 
    { { 'x','t','s','u', 0x00 }, { 0x3063, 0x00 }, }, // 
    { { 't','y','a', 0x00 }, { 0x3061, 0x3083, 0x00 }, }, // 
    { { 'c','y','a', 0x00 }, { 0x3061, 0x3083, 0x00 }, }, // 
    { { 'c','h','a', 0x00 }, { 0x3061, 0x3083, 0x00 }, }, // 
    { { 't','y','i', 0x00 }, { 0x3061, 0x3043, 0x00 }, }, // 
    { { 'c','y','i', 0x00 }, { 0x3061, 0x3043, 0x00 }, }, // 
    { { 't','y','u', 0x00 }, { 0x3061, 0x3085, 0x00 }, }, // 
    { { 'c','y','u', 0x00 }, { 0x3061, 0x3085, 0x00 }, }, // 
    { { 'c','h','u', 0x00 }, { 0x3061, 0x3085, 0x00 }, }, // 
    { { 't','y','e', 0x00 }, { 0x3061, 0x3047, 0x00 }, }, // 
    { { 'c','y','e', 0x00 }, { 0x3061, 0x3047, 0x00 }, }, // 
    { { 'c','h','e', 0x00 }, { 0x3061, 0x3047, 0x00 }, }, // 
    { { 't','y','o', 0x00 }, { 0x3061, 0x3087, 0x00 }, }, // 
    { { 'c','y','o', 0x00 }, { 0x3061, 0x3087, 0x00 }, }, // 
    { { 'c','h','o', 0x00 }, { 0x3061, 0x3087, 0x00 }, }, // 
    { { 't','s','a', 0x00 }, { 0x3064, 0x3041, 0x00 }, }, // 
    { { 't','s','i', 0x00 }, { 0x3064, 0x3043, 0x00 }, }, // 
    { { 't','s','e', 0x00 }, { 0x3064, 0x3047, 0x00 }, }, // 
    { { 't','s','o', 0x00 }, { 0x3064, 0x3049, 0x00 }, }, // 
    { { 't','h','a', 0x00 }, { 0x3066, 0x3083, 0x00 }, }, // Ă
    { { 't','h','i', 0x00 }, { 0x3066, 0x3043, 0x00 }, }, // Ă
    { { 't','h','u', 0x00 }, { 0x3066, 0x3085, 0x00 }, }, // Ă
    { { 't','h','e', 0x00 }, { 0x3066, 0x3047, 0x00 }, }, // Ă
    { { 't','h','o', 0x00 }, { 0x3066, 0x3087, 0x00 }, }, // Ă
    { { 't','w','u', 0x00 }, { 0x3068, 0x3045, 0x00 }, }, // Ƃ
    { { 'n','a', 0x00 }, { 0x306a, 0x00 }, }, // 
    { { 'n','i', 0x00 }, { 0x306b, 0x00 }, }, // 
    { { 'n','u', 0x00 }, { 0x306c, 0x00 }, }, // 
    { { 'n','e', 0x00 }, { 0x306d, 0x00 }, }, // 
    { { 'n','o', 0x00 }, { 0x306e, 0x00 }, }, // 
    { { 'n','y','a', 0x00 }, { 0x306b, 0x3083, 0x00 }, }, // ɂ
    { { 'n','y','i', 0x00 }, { 0x306b, 0x3043, 0x00 }, }, // ɂ
    { { 'n','y','u', 0x00 }, { 0x306b, 0x3085, 0x00 }, }, // ɂ
    { { 'n','y','e', 0x00 }, { 0x306b, 0x3047, 0x00 }, }, // ɂ
    { { 'n','y','o', 0x00 }, { 0x306b, 0x3087, 0x00 }, }, // ɂ
    { { 'h','a', 0x00 }, { 0x306f, 0x00 }, }, // 
    { { 'h','i', 0x00 }, { 0x3072, 0x00 }, }, // 
    { { 'h','u', 0x00 }, { 0x3075, 0x00 }, }, // 
    { { 'f','u', 0x00 }, { 0x3075, 0x00 }, }, // 
    { { 'h','e', 0x00 }, { 0x3078, 0x00 }, }, // 
    { { 'h','o', 0x00 }, { 0x307b, 0x00 }, }, // 
    { { 'h','y','a', 0x00 }, { 0x3072, 0x3083, 0x00 }, }, // Ђ
    { { 'h','y','i', 0x00 }, { 0x3072, 0x3043, 0x00 }, }, // Ђ
    { { 'h','y','u', 0x00 }, { 0x3072, 0x3085, 0x00 }, }, // Ђ
    { { 'h','y','e', 0x00 }, { 0x3072, 0x3047, 0x00 }, }, // Ђ
    { { 'h','y','o', 0x00 }, { 0x3072, 0x3087, 0x00 }, }, // Ђ
    { { 'f','a', 0x00 }, { 0x3075, 0x3041, 0x00 }, }, // ӂ
    { { 'f','i', 0x00 }, { 0x3075, 0x3043, 0x00 }, }, // ӂ
    { { 'f','e', 0x00 }, { 0x3075, 0x3047, 0x00 }, }, // ӂ
    { { 'f','o', 0x00 }, { 0x3075, 0x3049, 0x00 }, }, // ӂ
    { { 'f','y','a', 0x00 }, { 0x3075, 0x3041, 0x00 }, }, // ӂ
    { { 'f','y','i', 0x00 }, { 0x3075, 0x3043, 0x00 }, }, // ӂ
    { { 'f','y','u', 0x00 }, { 0x3075, 0x3085, 0x00 }, }, // ӂ
    { { 'f','y','e', 0x00 }, { 0x3075, 0x3047, 0x00 }, }, // ӂ
    { { 'f','y','o', 0x00 }, { 0x3075, 0x3087, 0x00 }, }, // ӂ
    { { 'm','a', 0x00 }, { 0x307e, 0x00 }, }, // 
    { { 'm','i', 0x00 }, { 0x307f, 0x00 }, }, // 
    { { 'm','u', 0x00 }, { 0x3080, 0x00 }, }, // 
    { { 'm','e', 0x00 }, { 0x3081, 0x00 }, }, // 
    { { 'm','o', 0x00 }, { 0x3082, 0x00 }, }, // 
    { { 'm','y','a', 0x00 }, { 0x307f, 0x3083, 0x00 }, }, // ݂
    { { 'm','y','i', 0x00 }, { 0x307f, 0x3043, 0x00 }, }, // ݂
    { { 'm','y','u', 0x00 }, { 0x307f, 0x3085, 0x00 }, }, // ݂
    { { 'm','y','e', 0x00 }, { 0x307f, 0x3047, 0x00 }, }, // ݂
    { { 'm','y','o', 0x00 }, { 0x307f, 0x3087, 0x00 }, }, // ݂
    { { 'y','a', 0x00 }, { 0x3084, 0x00 }, }, // 
    { { 'y','i', 0x00 }, { 0x3044, 0x00 }, }, // 
    { { 'y','u', 0x00 }, { 0x3086, 0x00 }, }, // 
    { { 'y','e', 0x00 }, { 0x3044, 0x3047, 0x00 }, }, // 
    { { 'y','o', 0x00 }, { 0x3088, 0x00 }, }, // 
    { { 'r','a', 0x00 }, { 0x3089, 0x00 }, }, // 
    { { 'r','i', 0x00 }, { 0x308a, 0x00 }, }, // 
    { { 'r','u', 0x00 }, { 0x308b, 0x00 }, }, // 
    { { 'r','e', 0x00 }, { 0x308c, 0x00 }, }, // 
    { { 'r','o', 0x00 }, { 0x308d, 0x00 }, }, // 
    { { 'r','y','a', 0x00 }, { 0x308a, 0x3083, 0x00 }, }, // 
    { { 'r','y','i', 0x00 }, { 0x308a, 0x3043, 0x00 }, }, // 股
    { { 'r','y','u', 0x00 }, { 0x308a, 0x3085, 0x00 }, }, // 
    { { 'r','y','e', 0x00 }, { 0x308a, 0x3047, 0x00 }, }, // 肥
    { { 'r','y','o', 0x00 }, { 0x308a, 0x3087, 0x00 }, }, // 
    { { 'w','a', 0x00 }, { 0x308f, 0x00 }, }, // 
    { { 'w','i', 0x00 }, { 0x3046, 0x3043, 0x00 }, }, // 
    { { 'w','u', 0x00 }, { 0x3046, 0x00 }, }, // 
    { { 'w','e', 0x00 }, { 0x3046, 0x3047, 0x00 }, }, // 
    { { 'w','o', 0x00 }, { 0x3092, 0x00 }, }, // 
    { { 'l','w','a', 0x00 }, { 0x308f, 0x00 }, }, // 
    { { 'x','w','a', 0x00 }, { 0x308f, 0x00 }, }, // 
    { { 'n','b', 0x00 }, { 0x3093, 0x0062, 0x00 }, }, // b
    { { 'n','c', 0x00 }, { 0x3093, 0x0063, 0x00 }, }, // c
    { { 'n','d', 0x00 }, { 0x3093, 0x0064, 0x00 }, }, // d
    { { 'n','f', 0x00 }, { 0x3093, 0x0066, 0x00 }, }, // f
    { { 'n','g', 0x00 }, { 0x3093, 0x0067, 0x00 }, }, // g
    { { 'n','h', 0x00 }, { 0x3093, 0x0068, 0x00 }, }, // h
    { { 'n','j', 0x00 }, { 0x3093, 0x006a, 0x00 }, }, // j
    { { 'n','k', 0x00 }, { 0x3093, 0x006b, 0x00 }, }, // k
    { { 'n','l', 0x00 }, { 0x3093, 0x006c, 0x00 }, }, // l
    { { 'n','m', 0x00 }, { 0x3093, 0x006d, 0x00 }, }, // m
    { { 'n','p', 0x00 }, { 0x3093, 0x0070, 0x00 }, }, // p
    { { 'n','q', 0x00 }, { 0x3093, 0x0071, 0x00 }, }, // q
    { { 'n','r', 0x00 }, { 0x3093, 0x0072, 0x00 }, }, // r
    { { 'n','s', 0x00 }, { 0x3093, 0x0073, 0x00 }, }, // s
    { { 'n','t', 0x00 }, { 0x3093, 0x0074, 0x00 }, }, // t
    { { 'n','v', 0x00 }, { 0x3093, 0x0076, 0x00 }, }, // v
    { { 'n','w', 0x00 }, { 0x3093, 0x0077, 0x00 }, }, // w
    { { 'n','z', 0x00 }, { 0x3093, 0x007a, 0x00 }, }, // z
    { { 'n','n', 0x00 }, { 0x3093, 0x00 }, }, // 
    { { 'n','\n', 0x00 }, { 0x3093, 0x00 }, }, // 
    { { 'n',',', 0x00 }, { 0x3093, 0x002c, 0x00 }, }, // ,
    { { 'n','.', 0x00 }, { 0x3093, 0x002e, 0x00 }, }, // .
    { { 'g','a', 0x00 }, { 0x304c, 0x00 }, }, // 
    { { 'g','i', 0x00 }, { 0x304e, 0x00 }, }, // 
    { { 'g','u', 0x00 }, { 0x3050, 0x00 }, }, // 
    { { 'g','e', 0x00 }, { 0x3052, 0x00 }, }, // 
    { { 'g','o', 0x00 }, { 0x3054, 0x00 }, }, // 
    { { 'g','y','a', 0x00 }, { 0x304e, 0x3083, 0x00 }, }, // 
    { { 'g','y','i', 0x00 }, { 0x304e, 0x3043, 0x00 }, }, // 
    { { 'g','y','u', 0x00 }, { 0x304e, 0x3085, 0x00 }, }, // 
    { { 'g','y','e', 0x00 }, { 0x304e, 0x3047, 0x00 }, }, // 
    { { 'g','y','o', 0x00 }, { 0x304e, 0x3087, 0x00 }, }, // 
    { { 'g','w','a', 0x00 }, { 0x3050, 0x3041, 0x00 }, }, // 
    { { 'z','a', 0x00 }, { 0x3056, 0x00 }, }, // 
    { { 'z','i', 0x00 }, { 0x3058, 0x00 }, }, // 
    { { 'j','i', 0x00 }, { 0x3058, 0x00 }, }, // 
    { { 'z','u', 0x00 }, { 0x305a, 0x00 }, }, // 
    { { 'z','e', 0x00 }, { 0x305c, 0x00 }, }, // 
    { { 'z','o', 0x00 }, { 0x305e, 0x00 }, }, // 
    { { 'j','a', 0x00 }, { 0x3058, 0x3083, 0x00 }, }, // 
    { { 'j','y','a', 0x00 }, { 0x3058, 0x3083, 0x00 }, }, // 
    { { 'z','y','a', 0x00 }, { 0x3058, 0x3083, 0x00 }, }, // 
    { { 'j','y','i', 0x00 }, { 0x3058, 0x3043, 0x00 }, }, // 
    { { 'z','y','i', 0x00 }, { 0x3058, 0x3043, 0x00 }, }, // 
    { { 'j','u', 0x00 }, { 0x3058, 0x3085, 0x00 }, }, // 
    { { 'j','y','u', 0x00 }, { 0x3058, 0x3085, 0x00 }, }, // 
    { { 'z','y','u', 0x00 }, { 0x3058, 0x3085, 0x00 }, }, // 
    { { 'j','e', 0x00 }, { 0x3058, 0x3047, 0x00 }, }, // 
    { { 'j','y','e', 0x00 }, { 0x3058, 0x3047, 0x00 }, }, // 
    { { 'z','y','e', 0x00 }, { 0x3058, 0x3047, 0x00 }, }, // 
    { { 'j','o', 0x00 }, { 0x3058, 0x3087, 0x00 }, }, // 
    { { 'j','y','o', 0x00 }, { 0x3058, 0x3087, 0x00 }, }, // 
    { { 'z','y','o', 0x00 }, { 0x3058, 0x3087, 0x00 }, }, // 
    { { 'd','a', 0x00 }, { 0x3060, 0x00 }, }, // 
    { { 'd','i', 0x00 }, { 0x3062, 0x00 }, }, // 
    { { 'd','u', 0x00 }, { 0x3065, 0x00 }, }, // 
    { { 'd','e', 0x00 }, { 0x3067, 0x00 }, }, // 
    { { 'd','o', 0x00 }, { 0x3069, 0x00 }, }, // 
    { { 'd','y','a', 0x00 }, { 0x3062, 0x3083, 0x00 }, }, // 
    { { 'd','y','i', 0x00 }, { 0x3062, 0x3043, 0x00 }, }, // 
    { { 'd','y','u', 0x00 }, { 0x3062, 0x3085, 0x00 }, }, // 
    { { 'd','y','e', 0x00 }, { 0x3062, 0x3047, 0x00 }, }, // 
    { { 'd','y','o', 0x00 }, { 0x3062, 0x3087, 0x00 }, }, // 
    { { 'd','h','a', 0x00 }, { 0x3067, 0x3083, 0x00 }, }, // ł
    { { 'd','h','i', 0x00 }, { 0x3067, 0x3043, 0x00 }, }, // ł
    { { 'd','h','u', 0x00 }, { 0x3067, 0x3085, 0x00 }, }, // ł
    { { 'd','h','e', 0x00 }, { 0x3067, 0x3047, 0x00 }, }, // ł
    { { 'd','h','o', 0x00 }, { 0x3067, 0x3087, 0x00 }, }, // ł
    { { 'd','w','u', 0x00 }, { 0x3069, 0x3045, 0x00 }, }, // ǂ
    { { 'b','a', 0x00 }, { 0x3070, 0x00 }, }, // 
    { { 'b','i', 0x00 }, { 0x3073, 0x00 }, }, // 
    { { 'b','u', 0x00 }, { 0x3076, 0x00 }, }, // 
    { { 'b','e', 0x00 }, { 0x3079, 0x00 }, }, // 
    { { 'b','o', 0x00 }, { 0x307c, 0x00 }, }, // 
    { { 'p','a', 0x00 }, { 0x3071, 0x00 }, }, // 
    { { 'p','i', 0x00 }, { 0x3074, 0x00 }, }, // 
    { { 'p','u', 0x00 }, { 0x3077, 0x00 }, }, // 
    { { 'p','e', 0x00 }, { 0x307a, 0x00 }, }, // 
    { { 'p','o', 0x00 }, { 0x307d, 0x00 }, }, // 
    { { 'p','y','a', 0x00 }, { 0x3074, 0x3083, 0x00 }, }, // ҂
    { { 'p','y','i', 0x00 }, { 0x3074, 0x3043, 0x00 }, }, // ҂
    { { 'p','y','u', 0x00 }, { 0x3074, 0x3085, 0x00 }, }, // ҂
    { { 'p','y','e', 0x00 }, { 0x3074, 0x3047, 0x00 }, }, // ҂
    { { 'p','y','o', 0x00 }, { 0x3074, 0x3087, 0x00 }, }, // ҂
    { { 'b','y','a', 0x00 }, { 0x3073, 0x3083, 0x00 }, }, // т
    { { 'b','y','i', 0x00 }, { 0x3073, 0x3043, 0x00 }, }, // т
    { { 'b','y','u', 0x00 }, { 0x3073, 0x3085, 0x00 }, }, // т
    { { 'b','y','e', 0x00 }, { 0x3073, 0x3047, 0x00 }, }, // т
    { { 'b','y','o', 0x00 }, { 0x3073, 0x3087, 0x00 }, }, // т
    { { 'v','a', 0x00 }, { 0x3046, 0x309b, 0x3041, 0x00 }, }, // J
    { { 'v','i', 0x00 }, { 0x3046, 0x309b, 0x3043, 0x00 }, }, // J
    { { 'v','u', 0x00 }, { 0x3046, 0x309b, 0x00 }, }, // J
    { { 'v','e', 0x00 }, { 0x3046, 0x309b, 0x3047, 0x00 }, }, // J
    { { 'v','o', 0x00 }, { 0x3046, 0x309b, 0x3049, 0x00 }, }, // J
    { { 'x','a', 0x00 }, { 0x3041, 0x00 }, }, // 
    { { 'l','a', 0x00 }, { 0x3041, 0x00 }, }, // 
    { { 'x','i', 0x00 }, { 0x3043, 0x00 }, }, // 
    { { 'l','i', 0x00 }, { 0x3043, 0x00 }, }, // 
    { { 'x','u', 0x00 }, { 0x3045, 0x00 }, }, // 
    { { 'l','u', 0x00 }, { 0x3045, 0x00 }, }, // 
    { { 'x','e', 0x00 }, { 0x3047, 0x00 }, }, // 
    { { 'l','e', 0x00 }, { 0x3047, 0x00 }, }, // 
    { { 'x','o', 0x00 }, { 0x3049, 0x00 }, }, // 
    { { 'l','o', 0x00 }, { 0x3049, 0x00 }, }, // 
    { { 'l','y','a', 0x00 }, { 0x3083, 0x00 }, }, // 
    { { 'x','y','a', 0x00 }, { 0x3083, 0x00 }, }, // 
    { { 'l','y','u', 0x00 }, { 0x3043, 0x00 }, }, // 
    { { 'x','y','i', 0x00 }, { 0x3043, 0x00 }, }, // 
    { { 'l','y','u', 0x00 }, { 0x3085, 0x00 }, }, // 
    { { 'x','y','u', 0x00 }, { 0x3085, 0x00 }, }, // 
    { { 'l','y','e', 0x00 }, { 0x3047, 0x00 }, }, // 
    { { 'x','y','e', 0x00 }, { 0x3047, 0x00 }, }, // 
    { { 'l','y','o', 0x00 }, { 0x3087, 0x00 }, }, // 
    { { 'x','y','o', 0x00 }, { 0x3087, 0x00 }, }, // 
    { { 'l','k','a', 0x00 }, { 0x30f5, 0x00 }, }, // 
    { { 'x','k','a', 0x00 }, { 0x30f5, 0x00 }, }, // 
    { { 'l','k','e', 0x00 }, { 0x30f6, 0x00 }, }, // 
    { { 'x','k','e', 0x00 }, { 0x30f6, 0x00 }, }, // 
    { { 0x00 }, { 0x00 }, },                // e[ȕI[
  };
};

#endif /* !ROMAN_CONVERT_TBL_H */
